pub fn negotiate(client_handshake: &VersionHandshake) -> VersionResponseExpand description
Check if a client version is compatible with this server.
pub fn negotiate(client_handshake: &VersionHandshake) -> VersionResponseCheck if a client version is compatible with this server.